==> haskell-binary-parser-0.5.6-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 binary-parser
version:              0.5.6
visibility:           public
id:                   binary-parser-0.5.6-Gnp11ypMBns5RiFeDwoMl6
key:                  binary-parser-0.5.6-Gnp11ypMBns5RiFeDwoMl6
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/binary-parser
synopsis:
    A highly-efficient but limited parser API specialised for bytestrings

category:             Parser, Binary
abi:                  18e51d860d6451ff9875ccf5c03325bd
exposed:              True
exposed-modules:      BinaryParser
hidden-modules:       BinaryParser.Prelude
import-dirs:          /usr/lib/ghc-8.10.4/site-local/binary-parser-0.5.6
library-dirs:         /usr/lib/ghc-8.10.4/site-local/binary-parser-0.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/binary-parser-0.5.6
hs-libraries:         HSbinary-parser-0.5.6-Gnp11ypMBns5RiFeDwoMl6
depends:
    base-4.14.1.0 bytestring-0.10.12.0 mtl-2.2.2 text-1.2.4.1
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-binary-parser/html/binary-parser.haddock

haddock-html:         /usr/share/doc/haskell-binary-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-parser-0.5.6-122-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 binary-parser
version:              0.5.6
visibility:           public
id:                   binary-parser-0.5.6-DgqTjHP8YXi9wh27q6niCr
key:                  binary-parser-0.5.6-DgqTjHP8YXi9wh27q6niCr
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/binary-parser
synopsis:
    A highly-efficient but limited parser API specialised for bytestrings

category:             Parser, Binary
abi:                  d23500d8676e42b1bf28b1657443bb58
exposed:              True
exposed-modules:      BinaryParser
hidden-modules:       BinaryParser.Prelude
import-dirs:          /usr/lib/ghc-8.10.4/site-local/binary-parser-0.5.6
library-dirs:         /usr/lib/ghc-8.10.4/site-local/binary-parser-0.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/binary-parser-0.5.6
hs-libraries:         HSbinary-parser-0.5.6-DgqTjHP8YXi9wh27q6niCr
depends:
    base-4.14.1.0 bytestring-0.10.12.0 mtl-2.2.2 text-1.2.4.1
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-binary-parser/html/binary-parser.haddock

haddock-html:         /usr/share/doc/haskell-binary-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
